%bcond_without check

# https://github.com/git-lfs/git-lfs
%global goipath         github.com/git-lfs/git-lfs
Version:                2.12.1

%gometa

%global common_description %{expand:
Git extension for versioning large files.}

%global godocs          docs LICENSE.md CHANGELOG.md CODE-OF-CONDUCT.md\\\
                        CONTRIBUTING.md README.md

Name:		git-lfs
Release:	%mkrel 1
Summary:    Git extension for versioning large files
Group:		Development/Tools

License:	MIT
URL:        https://git-lfs.github.io/
Source0:	https://github.com/git-lfs/git-lfs/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  golang(github.com/dpotapov/go-spnego)
BuildRequires:  golang(github.com/git-lfs/gitobj/v2) >= 2            
BuildRequires:  golang(github.com/git-lfs/gitobj/v2/errors) >= 2
BuildRequires:  golang(github.com/git-lfs/go-netrc/netrc) >= 0-0.1.20180827gite0e9ca4
BuildRequires:  golang(github.com/git-lfs/go-ntlm/ntlm)
BuildRequires:  golang(github.com/git-lfs/wildmatch) >= 1.0.4
BuildRequires:  golang(github.com/mattn/go-isatty) >= 0.0.4
BuildRequires:  golang(github.com/olekukonko/ts)
BuildRequires:  golang(github.com/pkg/errors)
BuildRequires:  golang(github.com/rubyist/tracerx)
BuildRequires:  golang(github.com/spf13/cobra) >= 0.0.3
BuildRequires:  golang(github.com/ssgelm/cookiejarparser) >= 1.0.1
BuildRequires:  golang(golang.org/x/net/http2)
BuildRequires:  golang(golang.org/x/sync/semaphore)

# Generate man pages
BuildRequires:  ruby-ronn

%if %{with check}
# Tests
BuildRequires:  golang(github.com/stretchr/testify/assert) >= 1.5.1
BuildRequires:  golang(github.com/stretchr/testify/require) >= 1.5.1
BuildRequires:  golang(github.com/xeipuuv/gojsonschema)
BuildRequires:  perl-devel
BuildRequires:  perl-Test-Harness
# Tests require full git suite, but not generally needed.
BuildRequires:	git >= 1.8.5
%endif

Requires:	git >= 1.8.5

%description
Git Large File Storage (LFS) replaces large files such as audio samples,
videos, datasets, and graphics with text pointers inside Git, while
storing the file contents on a remote server.


%gopkg


%prep
%goprep

# Modify Makefile so that it expects binaries where we build them.
sed -i -e 's!\.\./bin/!/%{gobuilddir}/bin/!g' t/Makefile

%build
# Build manpages first (some embedding in the executable is done.)
pushd docs
ronn --roff man/*.ronn
%gobuild -o %{gobuilddir}/bin/mangen man/mangen.go
%{gobuilddir}/bin/mangen
popd

LDFLAGS="-X 'github.com/git-lfs/git-lfs/config.Vendor=Mageia %{mageia}' " \
%gobuild -o %{gobuilddir}/bin/git-lfs %{goipath}

# Build test executables
for cmd in t/cmd/*.go; do
    %gobuild -o "%{gobuilddir}/bin/$(basename $cmd .go)" "$cmd"
done
%gobuild -o "%{gobuilddir}/bin/git-lfs-test-server-api" t/git-lfs-test-server-api/*.go


%install
%gopkginstall
install -D -m 755 %{gobuilddir}/bin/git-lfs %{buildroot}%{_bindir}/%{name}
install -d %{buildroot}%{_mandir}/man1/
install -m 644 docs/man/*.1 %{buildroot}%{_mandir}/man1/
install -d %{buildroot}%{_mandir}/man5/
install -m 644 docs/man/*.5 %{buildroot}%{_mandir}/man5/


%post
%{_bindir}/git-lfs install --system --skip-repo

%preun
if [ $1 -eq 0 ]; then
    %{_bindir}/git-lfs uninstall  --system --skip-repo
fi
exit 0

%if %{with check}
%check
%gocheck
PATH=%{buildroot}%{_bindir}:%{gobuilddir}/bin:$PATH \
    make -C t PROVE_EXTRA_ARGS="-j$(getconf _NPROCESSORS_ONLN)"
%endif

%files
%doc LICENSE.md README.md CHANGELOG.md docs
%{_bindir}/git-lfs
%{_mandir}/man1/*.1.*
%{_mandir}/man5/*.5.*

%gopkgfiles


%changelog
* Tue Nov 10 2020 guillomovitch <guillomovitch> 2.12.1-1.mga8
+ Revision: 1644328
- new version 2.12.1

* Sat Sep 05 2020 guillomovitch <guillomovitch> 2.12.0-1.mga8
+ Revision: 1622264
- new version 2.12.0

* Tue May 12 2020 guillomovitch <guillomovitch> 2.11.0-1.mga8
+ Revision: 1583422
- new version 2.11.0

* Sat Mar 14 2020 guillomovitch <guillomovitch> 2.10.0-1.mga8
+ Revision: 1556387
- new version 2.10.0
+ bcornec <bcornec>
- Import git-mfs using fedora as a base
- Created package structure for git-lfs.

